@@ -38,6 +38,7 @@ class BuiltInProvider(ITestProvider):
         'gtkperf',
         'leb_basic_graphics',
         'ltp',
+        'ltp-snowball-tests',
         'lttng',
         'peacekeeper',
         'perf',
@@ -47,6 +48,7 @@ class BuiltInProvider(ITestProvider):
         'smem',
         'stream',
         'tiobench',
+        'tjbench',
         'x11perf',
         'xrestop',
         'wifi_enablement',
